"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mock = require("mock-fs");
const load_1 = require("./load");
const _1 = require(".");
describe('load()', () => {
    afterEach(mock.restore);
    it('throws an Error if the file does not exist', () => {
        mock();
        expect(() => { load_1.load(); }).toThrowError('Redprint file does not exist');
    });
    it('returns an Redprint if the file does not exist', () => {
        mock({ 'redprint.json': '{}' });
        expect(load_1.load()).toEqual({});
    });
});
describe('validate()', () => {
    afterEach(mock.restore);
    it('throws an Error if key is invalid', () => {
        mock({
            'redprint.json': JSON.stringify({
                Model: {
                    attribute1: {
                        validation: 'input => true'
                    },
                    attribute2: {
                        validation: 'input => false'
                    }
                }
            })
        });
        const input = 'hello';
        expect(() => { _1.validate('Model', input); }).toThrowError('Invalid key');
    });
    it('throws an Error if input cannot pass some validation', () => {
        mock({
            'redprint.json': JSON.stringify({
                Model: {
                    attribute: {
                        validation: 'input => false'
                    }
                }
            })
        });
        const input = 'hello';
        expect(() => { _1.validate('Model.attribute', input); }).toThrowError("'hello' is invalid Model.attribute for 'validation' validation");
    });
    it('returns boolean', () => {
        mock({
            'redprint.json': JSON.stringify({
                Model: {
                    attribute: {
                        validation: 'input => true'
                    }
                }
            })
        });
        const input = 'hello';
        expect(_1.validate('Model.attribute', input)).toBeTruthy();
    });
});
//# sourceMappingURL=test.js.map